### Name: pzelig
### Title: Perturbations-based Sensitivity Analysis of Zelig Models
### Aliases: pzelig
### Keywords: misc optimize

### ** Examples


# Sensitivity analysis of the classic longley data, as run through zelig.
#
# Note: Compare to the example documented under the main perturb page.

# example requires Zelig.

 if (library(Zelig,logical.return=TRUE)) {  
   data(longley)

   zelig.out=zelig(Employed~.,"ls",longley) # run longley regression
   # default settings
   perturb.zelig.out = pzelig(zelig.out)                   

   # Note: without zelig, the preceding would be:  perturb.out = perturb(longley,lm,Employed~.) 

   # plots the perturbed lm replications individually
   plot(perturb.zelig.out)        
   # summarizes the overall sensitivity of coefficient estimates
   summary(perturb.zelig.out)             
   plot(summary(perturb.zelig.out))
   
   # since the "ls" model relies on "lm" which supports anova, can summarize
   # using anova
   anova(perturb.zelig.out)
   plot(anova(perturb.zelig.out))
   
   # Up to this point, we could have done this without Zelig... here's the fun part.
  
   # set values of explanatory variables
   setx.out=setx(perturb.zelig.out, Year=1955)       

   # Note: could also have used setx.out=setx(z,Year=1955)  instead of the line above,
   #       or  simply called psim() below without setx.out, which would default to using setx(perturb.zelig.out)

   # use simulation to predict value of explanatory variable based on
   # 
   sim.perturb.zelig.out = psim(perturb.zelig.out,setx.out)

   # this plots the profile of the predicted distribution of the explanatory variable, Employed
   # around the point wher Year=1955, and other explanatory variables are at their midpoints

   plot(sim.perturb.zelig.out)

   # this provides a summary of the predicted distribution of the explanatory variable

   summary(sim.perturb.zelig.out)
   
 }



